==> dokuwiki-2013.05.10.tgz: dokuwiki/lib/plugins/authmysql/lang/ru/settings.php <==
<?php
/**
 * Russian language file
 *
 * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
 */
$lang['server']                = 'Ваш MySQL-сервер';
$lang['user']                  = 'Имя пользователя MySQL';
$lang['password']              = 'Пароль пользователя MySQL';
$lang['database']              = 'Имя базы данных';
$lang['charset']               = 'Используемый набор символов в базе данных';
$lang['debug']                 = 'Отображение дополнительной отладочной информации';
$lang['forwardClearPass']      = 'Передача пароля пользователя открытым текстом, вместо зашифрованной формы в используемом выражении SQL';
$lang['TablesToLock']          = 'Имена таблиц (через запятую), которые необходимо ограничение для записи';
$lang['checkPass']             = 'Выражение SQL, осуществляющее проверку пароля';
$lang['getUserInfo']           = 'Выражение SQL, осуществляющее извлечение информации о пользователе';
$lang['getGroups']             = 'Выражение SQL, осуществляющее извлечение информации о членстве пользователе в группах';
$lang['getUsers']              = 'Выражение SQL, осуществляющее извлечение полного списка пользователей';
$lang['FilterLogin']           = 'Выражение SQL, осуществляющее фильтрацию пользователей по пользовательскому имени';
$lang['FilterName']            = 'Выражение SQL, осуществляющее фильтрацию пользователей по полному имени';
$lang['FilterEmail']           = 'Выражение SQL, осуществляющее фильтрацию пользователей по адресу электронной почты';
$lang['FilterGroup']           = 'Выражение SQL, осуществляющее фильтрацию пользователей согласно членству в группе';
$lang['SortOrder']             = 'Выражение SQL, осуществляющее сортировку пользователей';
$lang['addUser']               = 'Выражение SQL, осуществляющее добавление нового опльзователя';
$lang['addGroup']              = 'Выражение SQL, осуществляющее добавление новой группы';
$lang['addUserGroup']          = 'Выражение SQL, осуществляющее добавление пользователя в существующую группу';
$lang['delGroup']              = 'Выражение SQL, осуществляющее удаление группы';
$lang['getUserID']             = 'Выражение SQL, обеспечивающее получение первичного ключа пользователя';
$lang['delUser']               = 'Выражение SQL, осуществляющее удаление пользователя';
$lang['delUserRefs']           = 'Выражение SQL, осуществляющее удаление пользователя из всех групп';
$lang['updateUser']            = 'Выражение SQL, осуществляющее обновление профиля пользователя';
$lang['UpdateLogin']           = 'Условие для обновления имени пользователя';
$lang['UpdatePass']            = 'Условие для обновления пароля пользователя';
$lang['UpdateEmail']           = 'Условие для обновления адреса электронной почты пользователя';
$lang['UpdateName']            = 'Условие для обновления полного имени пользователя';
$lang['UpdateTarget']          = 'Условие для идентификации пользователя при обновлении';
$lang['delUserGroup']          = 'Выражение SQL, осуществляющее удаление пользователя из указанной группы';
$lang['getGroupID']            = 'Выражение SQL, обеспечивающее получение первичного ключа указанной группы';
$lang['debug_o_0']             = 'ни один из вариантов';
$lang['debug_o_1']             = 'только при возникновении ошибок';
$lang['debug_o_2']             = 'все SQL-запросы';

==> dokuwiki-2018.04.22ap1.tgz: dokuwiki/lib/plugins/authmysql/lang/ru/settings.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Yuriy Skalko <yuriy.skalko@gmail.com>
 * @author Ivan I. Udovichenko (sendtome@mymailbox.pp.ua)
 * @author Aleksandr Selivanov <alexgearbox@gmail.com>
 * @author Type-kun <workwork-1@yandex.ru>
 */
$lang['server']                = 'Ваш MySQL-сервер';
$lang['user']                  = 'Имя пользователя MySQL';
$lang['password']              = 'Пароль пользователя MySQL';
$lang['database']              = 'Имя базы данных';
$lang['charset']               = 'Используемый набор символов в базе данных';
$lang['debug']                 = 'Отображение дополнительной отладочной информации';
$lang['forwardClearPass']      = 'Передача пароля пользователя открытым текстом, вместо зашифрованной формы, в используемом выражении SQL';
$lang['TablesToLock']          = 'Имена таблиц (через запятую), которым необходимо ограничение для записи';
$lang['checkPass']             = 'Выражение SQL, осуществляющее проверку пароля';
$lang['getUserInfo']           = 'Выражение SQL, осуществляющее извлечение информации о пользователе';
$lang['getGroups']             = 'Выражение SQL, осуществляющее извлечение информации о членстве пользователе в группах';
$lang['getUsers']              = 'Выражение SQL, осуществляющее извлечение полного списка пользователей';
$lang['FilterLogin']           = 'Выражение SQL, осуществляющее фильтрацию пользователей по логину';
$lang['FilterName']            = 'Выражение SQL, осуществляющее фильтрацию пользователей по полному имени';
$lang['FilterEmail']           = 'Выражение SQL, осуществляющее фильтрацию пользователей по адресу электронной почты';
$lang['FilterGroup']           = 'Выражение SQL, осуществляющее фильтрацию пользователей согласно членству в группе';
$lang['SortOrder']             = 'Выражение SQL, осуществляющее сортировку пользователей';
$lang['addUser']               = 'Выражение SQL, осуществляющее добавление нового пользователя';
$lang['addGroup']              = 'Выражение SQL, осуществляющее добавление новой группы';
$lang['addUserGroup']          = 'Выражение SQL, осуществляющее добавление пользователя в существующую группу';
$lang['delGroup']              = 'Выражение SQL, осуществляющее удаление группы';
$lang['getUserID']             = 'Выражение SQL, обеспечивающее получение первичного ключа пользователя';
$lang['delUser']               = 'Выражение SQL, осуществляющее удаление пользователя';
$lang['delUserRefs']           = 'Выражение SQL, осуществляющее удаление пользователя из всех групп';
$lang['updateUser']            = 'Выражение SQL, осуществляющее обновление профиля пользователя';
$lang['UpdateLogin']           = 'Условие для обновления имени пользователя';
$lang['UpdatePass']            = 'Условие для обновления пароля пользователя';
$lang['UpdateEmail']           = 'Условие для обновления адреса электронной почты пользователя';
$lang['UpdateName']            = 'Условие для обновления полного имени пользователя';
$lang['UpdateTarget']          = 'Выражение \'LIMIT\' для идентификации пользователя при обновлении';
$lang['delUserGroup']          = 'Выражение SQL, осуществляющее удаление пользователя из указанной группы';
$lang['getGroupID']            = 'Выражение SQL, обеспечивающее получение первичного ключа указанной группы';
$lang['debug_o_0']             = 'ни один из вариантов';
$lang['debug_o_1']             = 'только при возникновении ошибок';
$lang['debug_o_2']             = 'все SQL-запросы';
